@@ -13,7 +13,11 @@ hashit <- function(source, organism, release, catNC=FALSE, ...) {
                       release,"/gencode.v",release,".transcripts.fa.gz")
       gtf <- paste0("ftp://ftp.ebi.ac.uk/pub/databases/gencode/Gencode_mouse/release_",
                     release,"/gencode.v",release,".annotation.gtf.gz")
-      genome <- "GRCm38"
+      if (as.numeric(sub("M", "", release)) >= 26) {
+        genome <- "GRCm39"
+      } else {
+        genome <- "GRCm38"
+      }
     }
   }
   
@@ -29,7 +33,9 @@ hashit <- function(source, organism, release, catNC=FALSE, ...) {
                   "GRCm38"
                 }
               } else if (organism == "Drosophila melanogaster") {
-                if (as.numeric(release) >= 103) {
+                if (as.numeric(release) >= 110) {
+                  "BDGP6.46"
+                } else if (as.numeric(release) >= 103) {
                   "BDGP6.32"
                 } else if (as.numeric(release) >= 99) {
                   "BDGP6.28"
@@ -101,12 +107,12 @@ hashit <- function(source, organism, release, catNC=FALSE, ...) {
 # download method
 m <- "wget"
 
-i <- 44
+i <- 46
 hashit("GENCODE", "Homo sapiens", i, method=m)
-i <- 33
+i <- 35
 hashit("GENCODE", "Mus musculus", paste0("M",i), method=m)
 #
-i <- 110
+i <- 112
 hashit("Ensembl", "Homo sapiens", i, method=m)
 hashit("Ensembl", "Mus musculus", i, method=m)
 hashit("Ensembl", "Drosophila melanogaster", i, method=m)
@@ -116,5 +122,5 @@ hashit("Ensembl", "Mus musculus", i, catNC=TRUE, method=m)
 hashit("Ensembl", "Drosophila melanogaster", i, catNC=TRUE, method=m)
 #
 # RefSeq permalink transcriptomes are rarely updated
-# hashit("RefSeq", "Homo sapiens", paste0("GRCh38.p",i), method=m)
-# hashit("RefSeq", "Mus musculus", paste0("GRCm38.p",i), method=m)
+hashit("RefSeq", "Homo sapiens", paste0("GRCh38.p",i), method=m)
+hashit("RefSeq", "Mus musculus", paste0("GRCm38.p",i), method=m)
